{
  description = "Home Manager configuration of Jane Doe";

  inputs = {
    # Specify the source of Home Manager and Nixpkgs.
    nixpkgs.url = "github:nixos/nixpkgs/nixos-23.11";
    nixpkgsUnstable.url = "github:nixos/nixpkgs/nixos-unstable";
    home-manager = {
      url = "github:nix-community/home-manager/release-23.11";
      inputs.nixpkgs.follows = "nixpkgs";
    };
    obs-streamfx = {
      url = "git+https://git.asonix.dog/asonix/nix-obs-streamfx";
      inputs.nixpkgs.follows = "nixpkgs";
    };
  };

  outputs = { nixpkgs, nixpkgsUnstable, home-manager, obs-streamfx, ... }:
    let
      system = "x86_64-linux";
      pkgsUnstable = import nixpkgsUnstable {
        inherit system;
        config.allowUnfree = true;
      };
      pkgs = import nixpkgs {
        inherit system;
        config.allowUnfree = true;

        overlays = [
          (final: prev: {
            dissent = pkgsUnstable.dissent;
            fractal = pkgsUnstable.fractal;
            keymapp = pkgsUnstable.keymapp;
            paper-plane = pkgsUnstable.paper-plane;
            signal-desktop = pkgsUnstable.signal-desktop;
            tuba = pkgsUnstable.tuba;
            vesktop = pkgsUnstable.vesktop;
            obs-studio-plugins = prev.obs-studio-plugins // {
              obs-streamfx = obs-streamfx.packages.${system}.obs-streamfx;
            };
          })
        ];
      };
    in
    {
      homeConfigurations.asonix = home-manager.lib.homeManagerConfiguration {
        inherit pkgs;

        # Specify your home configuration modules here, for example,
        # the path to your home.nix.
        modules = [
          ./home.nix
          ./nvim.nix
        ];

        # Optionally use extraSpecialArgs
        # to pass through arguments to home.nix
        # extraSpecialArgs = attrs // { inherit system; };
      };
    };
}
