{ config, pkgs, system, ... }:

let
  setIcon = ''
#!/usr/bin/env bash

dbus-send \
    --system \
    --print-reply \
    --type=method_call \
    --dest="org.freedesktop.Accounts" \
    /org/freedesktop/Accounts/User1000 \
    org.freedesktop.Accounts.User.SetIconFile \
    "string:$1"
  '';
in
{
  imports = [ ./zsh.nix ./ssh.nix ];

  home.username = "asonix";
  home.homeDirectory = "/home/asonix";

  home.file."lunarvim-config" = {
    enable = true;
    source = ./config.lua;
    target = ".config/lvim/config.lua";
  };

  home.packages = with pkgs; [
    ack
    bat
    bottom
    dig
    eza
    file
    htop
    hyfetch
    nvtop
    topgrade
    keymapp

    amberol
    carla
    cura
    dissent
    fluffychat
    fractal
    freecad
    gimp-with-plugins
    gnome.dconf-editor
    handbrake
    helvum
    krita
    libreoffice-fresh
    newsflash
    nextcloud-client
    paper-plane
    patchage
    pavucontrol
    prismlauncher
    shticker-book-unwritten
    signal-desktop
    tdesktop
    tuba
    ungoogled-chromium
    vesktop
    vlc
    wireshark

    picocom

    (writeShellScriptBin "set-icon" setIcon)
  ];

  home.stateVersion = "22.05";

  programs.home-manager.enable = true;
  programs.git = {
    enable = true;
    userName = "asonix";
    userEmail = "asonix@asonix.dog";
  };

  programs.bat.enable = true;

  programs.starship.enable = true;

  programs.direnv = {
    enable = true;
    nix-direnv.enable = true;
  };

  programs.obs-studio = {
    enable = true;
    plugins = with pkgs.obs-studio-plugins; [
      advanced-scene-switcher
      droidcam-obs
      input-overlay
      obs-3d-effect
      obs-backgroundremoval
      obs-command-source
      obs-freeze-filter
      obs-gradient-source
      obs-gstreamer
      obs-move-transition
      obs-multi-rtmp
      obs-mute-filter
      obs-pipewire-audio-capture
      obs-replay-source
      obs-rgb-levels-filter
      obs-scale-to-sound
      obs-shaderfilter
      obs-source-record
      obs-source-switcher
      obs-streamfx
      obs-teleport
      obs-text-pthread
      obs-transition-table
      obs-tuna
      obs-vaapi
      obs-vertical-canvas
      obs-vintage-filter
      obs-vkcapture
      waveform
      wlrobs
    ];
  };
}
